@@ -3,10 +3,11 @@ flexiblity model, which is a wrapper for all models of the
 pysimmods package.
 
 """
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 
 import mosaik_api
 import numpy as np
+import pandas as pd
 from pysimmods.mosaik import LOG
 from pysimmods.util.dateformat import GER
 from pysimmods.other.flexibility.flexibility_model import FlexibilityModel
@@ -53,9 +54,13 @@ class FlexibilitySimulator(mosaik_api.Simulator):
                 "Using default step size of 900."
             )
         self.step_size = sim_params.get("step_size", 900)
-        self.now_dt = datetime.strptime(sim_params["start_date"], GER)
+        self.now_dt = datetime.strptime(
+            sim_params["start_date"], GER
+        ).astimezone(timezone.utc)
 
         self.unit = sim_params.get("unit", "kw")
+        self.percent_factor = sim_params.get("percent_factor", 1.0)
+        self.priorize_schedule = sim_params.get("priorize_schedule", False)
         self.forecast_horizon_hours = sim_params.get(
             "forecast_horizon_hours", self.step_size / 3_600
         )
@@ -106,6 +111,8 @@ class FlexibilitySimulator(mosaik_api.Simulator):
                 self.num_schedules,
                 self.rng.randint(1_000_000),
                 self.unit,
+                self.percent_factor,
+                self.priorize_schedule,
             )
             self.num_models[model] += 1
             entities.append({"eid": eid, "type": model})
@@ -147,17 +154,21 @@ class FlexibilitySimulator(mosaik_api.Simulator):
         data = dict()
         for eid, attrs in outputs.items():
             data[eid] = dict()
-            model = eid.split("-")[0]
+            # model = eid.split("-")[0]
             for attr in attrs:
 
                 if attr == "flexibilities":
                     value = self.models[eid].flexibilities
                 elif attr == "schedule":
-                    value = self.models[eid].schedule._data.loc[
-                        self.now_dt : self.now_dt
-                        + timedelta(hours=self.forecast_horizon_hours)
-                        - timedelta(seconds=self.step_size)
-                    ]
+                    value = (
+                        self.models[eid]
+                        .schedule._data.loc[
+                            self.now_dt : self.now_dt
+                            + timedelta(hours=self.forecast_horizon_hours)
+                            - timedelta(seconds=self.step_size)
+                        ]
+                        .to_json()
+                    )
                 elif attr == "target":
                     value = self.models[eid].schedule._data.loc[
                         self.now_dt - timedelta(seconds=self.step_size)
@@ -208,11 +219,19 @@ class FlexibilitySimulator(mosaik_api.Simulator):
 
                 if "forecast" in attr:
                     for forecast in src_ids.values():
+                        if not isinstance(forecast, pd.DataFrame):
+                            forecast = pd.read_json(forecast).tz_localize(
+                                "UTC"
+                            )
                         self.models[eid].update_forecasts(forecast)
                     continue
                 elif attr == "schedule":
                     for schedule in src_ids.values():
                         if schedule is not None:
+                            if not isinstance(schedule, pd.DataFrame):
+                                schedule = pd.read_json(schedule).tz_localize(
+                                    "UTC"
+                                )
                             self.models[eid].update_schedule(schedule)
                     continue
 
