@@ -3,7 +3,7 @@ of the pysimmods package.
 
 """
 import pprint
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 
 import mosaik_api
 from pysimmods.mosaik import LOG
@@ -49,7 +49,9 @@ class PysimmodsSimulator(mosaik_api.Simulator):
                 "Using default step size of 900."
             )
         self.step_size = sim_params.get("step_size", 900)
-        self.now_dt = datetime.strptime(sim_params["start_date"], GER)
+        self.now_dt = datetime.strptime(
+            sim_params["start_date"], GER
+        ).astimezone(timezone.utc)
 
         return self.meta
 
