@@ -1,10 +1,9 @@
 """This module contains the :class:`ForecastModel`."""
-from datetime import datetime, timedelta
-
+from datetime import datetime, timedelta, timezone
 import numpy as np
-
-from pysimmods.util.dateformat import GER
 from pysimmods.other.flexibility.schedule import Schedule
+from pysimmods.util.dateformat import GER
+
 from . import LOG
 
 
@@ -13,15 +12,36 @@ class ForecastModel:
 
     Parameters
     ----------
-    model : :class:`.Model`
+    model: :class:`.Model`
         An instance of a subclass of the base model class (e.g.,
         :class:`.Battery` model).
-    start_date : str or datetime
+    start_date: str or datetime
         An ISO datetime string or a datetime object defining the start
         date.
-    step_size : int, optional
+    step_size: int, optional
         The step size of the model in seconds. Will be used as fallback
         if no step size is provided to the model. Defaults to 900.
+    forecast_horizon_hours: float, optional
+        The number of hours the model should create a forecast for.
+        If the model needs a weather forecast, this weather forecast
+        needs to be large enough.
+
+    Attributes
+    ----------
+    model: :class:`.Model`
+        A reference to the model.
+    now_dt: :class:`.datetime.datetime`
+        The current local time.
+    step_size: int
+        The step size of the model.
+    forecasts: :class:`pandas.DataFrame`
+        A dictionary containing forecasts for the inputs of the
+        underlying model.
+    flexibilities: dict
+        A dictionary containing the current flexibilities of the
+        underlying model.
+    schedule: :class:`.Schedule`
+        Contains the current schedule of the model.
 
     """
 
@@ -39,107 +59,46 @@ class ForecastModel:
         priorize_schedule=False,
     ):
         self.model = model
-        """A reference to the model"""
-
         if isinstance(start_date, str):
-            self.now_dt = datetime.strptime(start_date, GER)
+            self.now_dt = datetime.strptime(start_date, GER).astimezone(
+                tz=timezone.utc
+            )
         else:
             self.now_dt = start_date
-        """The current local time."""
-
         self.step_size = step_size
-        """The step size of the model."""
-
-        self.percent_factor = percent_factor
-        self.unit_factor = 1.0
-        self.pname = "p_kw"
-        self.qname = "q_kvar"
-        self.priorize_schedule = priorize_schedule
         self.forecasts = None
-        """A dictionary containing forecasts for the inputs of
-        the underlying model.
-        """
         self.flexibilities = None
-        """A dictionary containing the current flexibilities of
-        the underlying model.
-        """
-        self.forecast_horizon_hours = forecast_horizon_hours
-        self.num_schedules = num_schedules
+
+        self._percent_factor = percent_factor
+        self._priorize_schedule = priorize_schedule
+        self._fch_hours = forecast_horizon_hours
+        self._num_schedules = num_schedules
 
         if unit == "mw":
-            self.unit_factor = 0.001
-            self.pname = "p_mw"
-            self.qname = "q_mvar"
+            self._unit_factor = 0.001
+            self._pname = "p_mw"
+            self._qname = "q_mvar"
         elif unit == "w":
             self.unit_factor = 1000.0
-            self.pname = "p_w"
-            self.qname = "q_var"
+            self._pname = "p_w"
+            self._qname = "q_var"
+        else:
+            self._unit_factor = 1.0
+            self._pname = "p_kw"
+            self._qname = "q_kvar"
 
         self.schedule = Schedule(
             self.now_dt,
             self.step_size,
-            self.pname,
-            self.qname,
-            self.forecast_horizon_hours,
+            self._pname,
+            self._qname,
+            self._fch_hours,
         )
-        """A dictionary containing the schedule for the model."""
-        self.active_schedule_id = None
-        """A pointer to the currently active schedule."""
 
         if seed is not None:
-            self.rng = np.random.RandomState(seed)
+            self._rng = np.random.RandomState(seed)
         else:
-            self.rng = np.random.RandomState()
-
-    def update_forecasts(self, forecasts):
-        if self.forecasts is None:
-            self.forecasts = forecasts
-        else:
-            for col in forecasts.columns:
-                if col not in self.forecasts.columns:
-                    self.forecasts[col] = np.nan
-            for index, _ in forecasts.iterrows():
-                if index not in self.forecasts.index:
-                    break
-
-            self.forecasts.update(forecasts.loc[:index])
-            self.forecasts = self.forecasts.append(forecasts.loc[index:])
-
-            self.forecasts = self.forecasts[~self.forecasts.index.duplicated()]
-
-    def update_schedule(self, schedule):
-        self.schedule.update(schedule)
-
-    def _get_setpoint(self):
-        try:
-            schedule_set = self.schedule.get("target") / self.percent_factor
-        except TypeError:
-            schedule_set = None
-        try:
-            model_set = self.model.set_percent * self.percent_factor
-        except TypeError:
-            model_set = None
-
-        default_set = (
-            self.model.default_schedule[self.now_dt.hour] * self.percent_factor
-        )
-
-        priority = [model_set, schedule_set]
-
-        if self.priorize_schedule:
-            priority = priority[::-1]
-
-        priority.append(default_set)
-
-        setpoint = None
-        for setval in priority:
-            if setval is not None and ~np.isnan(setval):
-                setpoint = setval
-                break
-        else:
-            raise ValueError("Setpoint for model %s not set.", self.model)
-
-        return setpoint
+            self._rng = np.random.RandomState()
 
     def step(self):
         """Perform a simulation step of the underlying model.
@@ -157,14 +116,64 @@ class ForecastModel:
         self.schedule.update_row(
             self.now_dt,
             setpoint,
-            self.model.p_kw * self.unit_factor,
-            self.model.q_kvar * self.unit_factor,
+            self.model.p_kw * self._unit_factor,
+            self.model.q_kvar * self._unit_factor,
         )
         self._check_schedule()
 
         self.now_dt += timedelta(seconds=self.step_size)
         self.schedule.now_dt = self.now_dt
 
+    def update_forecasts(self, forecasts):
+        if self.forecasts is None:
+            self.forecasts = forecasts
+        else:
+            for col in forecasts.columns:
+                if col not in self.forecasts.columns:
+                    self.forecasts[col] = np.nan
+            for index, _ in forecasts.iterrows():
+                if index not in self.forecasts.index:
+                    break
+
+            self.forecasts.update(forecasts.loc[:index])
+            self.forecasts = self.forecasts.append(forecasts.loc[index:])
+            self.forecasts = self.forecasts[~self.forecasts.index.duplicated()]
+
+    def update_schedule(self, schedule):
+        self.schedule.update(schedule)
+
+    def _get_setpoint(self):
+        try:
+            schedule_set = self.schedule.get("target")
+        except TypeError:
+            schedule_set = None
+        try:
+            model_set = self.set_percent
+        except TypeError:
+            model_set = None
+
+        default_set = (
+            self.model.default_schedule[self.now_dt.hour]
+            * self._percent_factor
+        )
+
+        priority = [model_set, schedule_set]
+
+        if self._priorize_schedule:
+            priority = priority[::-1]
+
+        priority.append(default_set)
+
+        setpoint = None
+        for setval in priority:
+            if setval is not None and ~np.isnan(setval):
+                setpoint = setval
+                break
+        else:
+            raise ValueError("Setpoint for model %s not set.", self.model)
+
+        return setpoint
+
     def _check_inputs(self):
         if self.model.inputs.step_size is not None:
             self.step_size = self.model.inputs.step_size
@@ -185,13 +194,13 @@ class ForecastModel:
         state_backup = self.model.get_state()
 
         now = self.now_dt + timedelta(seconds=self.step_size)
-        periods = int(self.forecast_horizon_hours * 2 * 3_600 / self.step_size)
+        periods = int(self._fch_hours * 3_600 / self.step_size)
 
         for _ in range(periods):
             if not self.schedule.has_index(now):
                 self.schedule.update_row(now, np.nan, np.nan, np.nan)
             default_setpoint = (
-                self.model.default_schedule[now.hour] * self.percent_factor
+                self.model.default_schedule[now.hour] * self._percent_factor
             )
             if np.isnan(self.schedule.get("target", now)):
                 self.schedule.update_entry(now, "target", default_setpoint)
@@ -200,10 +209,10 @@ class ForecastModel:
                 self._perform_step(now, self.schedule.get("target", now))
 
                 self.schedule.update_entry(
-                    now, self.pname, self.model.p_kw * self.unit_factor
+                    now, self._pname, self.model.p_kw * self._unit_factor
                 )
                 self.schedule.update_entry(
-                    now, self.qname, self.model.q_kvar * self.unit_factor
+                    now, self._qname, self.model.q_kvar * self._unit_factor
                 )
 
             except KeyError:
@@ -243,8 +252,8 @@ class ForecastModel:
 
     @property
     def set_percent(self):
-        return self.model.set_percent * self.percent_factor
+        return self.model.set_percent * self._percent_factor
 
     @set_percent.setter
     def set_percent(self, set_percent):
-        self.model.set_percent = set_percent / self.percent_factor
+        self.model.set_percent = set_percent / self._percent_factor
